@@ -6,16 +6,10 @@ use Text::Hatena::FootnoteNode;
 
 sub parse {
     my $self = shift;
-    while ($self->{context}->hasnext) {
+    my $c = $self->{context};
+    while ($c->hasnext) {
         my $node = Text::Hatena::SectionNode->new(
-            context => $self->{context},
-            ilevel => $self->{ilevel},
-        );
-        $node->parse;
-    }
-    if (@{$self->{context}->footnotes}) {
-        my $node = Text::Hatena::FootnoteNode->new(
-            context => $self->{context},
+            context => $c,
             ilevel => $self->{ilevel},
         );
         $node->parse;
